@@ -1,4 +1,5 @@
-package File::Flat;
+package File::Flat; # git description: fabfdb3
+# ABSTRACT: Implements a flat filesystem
 
 # The File::Flat is a static class that provides a unified interface
 # to the filesystem in a way such that directories are abstracted away.
@@ -8,25 +9,22 @@ package File::Flat;
 
 use 5.005;
 use strict;
-use Cwd         ();
-use File::Spec  ();
-use IO::File    ();
-use prefork 'File::Slurp';
-use prefork 'File::Temp';
-use prefork 'File::Copy';
-use prefork 'File::NCopy';
-use prefork 'File::Remove';
+use Cwd        ();
+use File::Spec ();
+use IO::File   ();
+use prefork    'File::Temp';
+use prefork    'File::Copy';
+use prefork    'File::Copy::Recursive';
+use prefork    'File::Remove';
 
-use vars qw{$VERSION $errstr %modes $AUTO_PRUNE};
-BEGIN {
-	$VERSION = '0.96';
+our $VERSION = '1.05';
 
-	# The main error string
-	$errstr  = '';
+# The main error string
+our $errstr  = '';
 
-	# Create a map of all file open modes we support,
-	# and which ones will create a new file if needed.
-	%modes = ( 
+# Create a map of all file open modes we support,
+# and which ones will create a new file if needed.
+our %modes = ( 
 		'<'  => 0, 'r'  => 0, # Read
 		'+<' => 1, 'r+' => 1, # ReadWrite
 		'>'  => 1, 'w'  => 1, # Write
@@ -34,11 +32,7 @@ BEGIN {
 		'>>' => 1, 'a'  => 1  # Append
 		);
 
-	$AUTO_PRUNE = '';
-}
-
-
-
+our $AUTO_PRUNE = '';
 
 
 #####################################################################
@@ -173,16 +167,25 @@ sub getReadWriteHandle { $_[0]->open( '+<', $_[1] ) }
 # Returns undef on error.
 sub slurp {
 	my $class = shift;
-	my $file = shift or return undef;
+	my $file  = shift or return undef;
 
 	# Check the file
 	$class->canOpen( $file )
 		or return $class->_error( "Unable to open file '$file'" );
 
-	# Hand off to File::Slurp
-	require File::Slurp;
-	File::Slurp::read_file( $file, scalar_ref => 1 )
-		or $class->_error( "Error opening file '$file'", $! );
+	# Use idiomatic slurp instead of File::Slurp
+	_slurp($file) or $class->_error( "Error opening file '$file'", $! );
+}
+
+# Provide a simple _slurp implementation
+sub _slurp {
+	my $file = shift;
+	local $/ = undef;
+	local *SLURP;
+	CORE::open( SLURP, "<$file" ) or return undef;
+	my $source = <SLURP>;
+	CORE::close( SLURP ) or return undef;
+	\$source;
 }
 
 # read reads in an entire file, returning it as an array or a reference to it.
@@ -190,7 +193,7 @@ sub slurp {
 # the calling context.
 sub read {
 	my $class = shift;
-	my $file = shift or return;
+	my $file  = shift or return;
 
 	# Check the file
 	unless ( $class->canOpen( $file ) ) {
@@ -198,10 +201,15 @@ sub read {
 		return;
 	}
 
-	# Hand off to File::Slurp
-	require File::Slurp;
-	my @content = File::Slurp::read_file( $file );
+	# Load the file
+	unless ( CORE::open(FILE, $file) ) {
+		$class->_error( "Unable to open file '$file'" );
+		return;
+	}
+	my @content = <FILE>;
 	chomp @content;
+	CORE::close(FILE);
+
 	wantarray ? @content : \@content;
 }
 
@@ -367,9 +375,9 @@ sub copy {
 			"Failed to create directory '$target'" );
 	}
 
-	# Hand off to File::NCopy
-	require File::NCopy;
-	my $rv = File::NCopy::copy( \1, $tocopy, $target );
+	# Hand off to File::Copy::Recursive
+	require File::Copy::Recursive;
+	my $rv = File::Copy::Recursive::dircopy( $tocopy, $target );
 	defined $rv ? $rv : $class->_andRemove( $remove_on_fail );
 }
 
@@ -505,7 +513,7 @@ sub _andRemove {
 
 
 
-package File::Flat::Object;
+package File::Flat::Object; # git description: fabfdb3
 
 # Instantiatable version of File::Flat.
 # 
@@ -705,13 +713,14 @@ sub prune {
 		# Does it contain anything, other that (possibly) curdir and updir entries
 		opendir( PRUNEDIR, $dir )
 			or return $self->_error("opendir failed while pruning: $!");
-		foreach ( readdir PRUNEDIR ) {
+		my @files = readdir PRUNEDIR;
+		closedir PRUNEDIR;
+		foreach ( @files ) {
 			next if $_ eq File::Spec->curdir;
 			next if $_ eq File::Spec->updir;
 
 			# Found something, we don't need to prune this,
 			# or anything else for that matter.
-			closedir PRUNEDIR;
 			return 1;
 		}
 
@@ -819,25 +828,31 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 File::Flat - Implements a flat filesystem
 
-=head1 SYNOPSIS
+=head1 VERSION
+
+version 1.05
 
 =head1 DESCRIPTION
 
+=for stopwords FSI.pm VMS canExecute canOpen canRead canReadWrite canRemove canWrite cp getAppendHandle getReadHandle getReadWriteHandle getWriteHandle isaBinary isaDirectory isaFile isaText makeDirectory
+
 File::Flat implements a flat filesystem. A flat filesystem is a filesystem in
 which directories do not exist. It provides an abstraction over any normal
 filesystem which makes it appear as if directories do not exist. In effect,
 it will automatically create directories as needed. This is create for things
-like install scripts and such, as you never need to worry about the existance
+like install scripts and such, as you never need to worry about the existence
 of directories, just write to a file, no matter where it is.
 
 =head2 Comprehensive Implementation
 
 The implementation of File::Flat is extremely comprehensive in scope. It has
-methods for all stardard file interaction taks, the -X series of tests, and
+methods for all standard file interaction tasks, the -X series of tests, and
 some other things, such as slurp.
 
 All methods are statically called, for example, to write some stuff to a file.
@@ -848,8 +863,8 @@ All methods are statically called, for example, to write some stuff to a file.
 =head2 Use of other modules
 
 File::Flat tries to use more task orientated modules wherever possible. This
-includes the use of File::Copy, File::NCopy, File::Remove and others. These
-are mostly loaded on-demand.
+includes the use of L<File::Copy>, L<File::Copy::Recursive>, L<File::Remove>
+and others. These are mostly loaded on-demand.
 
 =head2 Pruning and $AUTO_PRUNE
 
@@ -884,19 +899,14 @@ this locally, such as in the following example.
 
 =head2 Non-Unix platforms
 
-File::Flat itself should be completely capable of handling any platform
-through its exclusive use of File::Spec.
-
-However, some of the modules it relies upon, particularly File::Remove, and
-possible File::NCopy are not File::Spec happy yet. Results may wary on non
-Unix platforms. Users of non-Unix platforms are invited to patch
-File::Remove ( and possibly File::NCopy ) and File::Flat should work.
+As of version 0.97 File::Flat should work correctly on Win32. Other
+platforms (such as VMS) are believed to work, but require confirmation.
 
 =head1 METHODS
 
 =head2 exists $filename 
 
-Tests for the existance of the file.
+Tests for the existence of the file.
 This is an exact duplicate of the -e function.
 
 =head2 isaFile $filename
@@ -1013,7 +1023,7 @@ The C<write> method is the main method for writing content to a file.
 It takes two arguments, the location to write to, and the content to write, 
 in several forms.
 
-If the file already exists, it will be clobered before writing starts.
+If the file already exists, it will be clobbered before writing starts.
 If the file doesn't exists, the file and any directories will be created as
 needed.
 
@@ -1073,7 +1083,7 @@ The C<remove> method will remove a file, or recursively remove a directory.
 
 If a second (true) argument is provided, then once the file or directory
 has been deleted, the method will the automatically work its way upwards
-pruning (deleting) empty and thus assumably useless directories.
+pruning (deleting) empty and thus presumably useless directories.
 
 Returns true if the deletion (and pruning if requested) was a success, or
 C<undef> otherwise.
@@ -1089,7 +1099,7 @@ Returns true, or C<undef> on error.
 
 =head2 truncate $filename [, $size ]
 
-The C<truncate> method will truncate an existing file to partular size.
+The C<truncate> method will truncate an existing file to a particular size.
 A size of 0 ( zero ) is used if no size is provided. If the file does not
 exists, it will be created, and set to 0. Attempting to truncate a 
 directory will fail.
@@ -1111,32 +1121,43 @@ Function interface to be written, like
 L<File::Spec::Functions>, to provide importable functions.
 
 There's something bigger here too, I'm not exactly sure what it is,
-but I think there might be the beginings of a unified filesystem
+but I think there might be the beginnings of a unified filesystem
 interface here... FSI.pm
 
-=head1 SUPPORT
-
-Bugs should be filed at via the CPAN bug tracker at:
-
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=File-Flat>
-
-For other issues or comments, contact the author
-
-=head1 AUTHORS
-
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
-
 =head1 SEE ALSO
 
 L<File::Spec>, L<http://ali.as/>
 
-=head1 COPYRIGHT
+=head1 SUPPORT
 
-Copyright (c) 2002 - 2006 Adam Kennedy. All rights reserved.
-This program is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=File-Flat>
+(or L<bug-File-Flat@rt.cpan.org|mailto:bug-File-Flat@rt.cpan.org>).
 
-The full text of the license can be found in the
-LICENSE file included with this module.
+=head1 AUTHOR
+
+Adam Kennedy <adamk@cpan.org>
+
+=head1 CONTRIBUTORS
+
+=for stopwords Adam Kennedy Karen Etheridge
+
+=over 4
+
+=item *
+
+Adam Kennedy <adam@ali.as>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2002 by Adam Kennedy.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
